# -*- coding: utf-8 -*-

from rest_framework import generics

from thux.api.views import QuerysetMixin
from thux.api.permissions import ThuxModelPermissions

from .. import models
from . import serializers


class OrderList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Order.objects.all()
    serializer_class = serializers.OrderSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(OrderList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class OrderRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Order.objects.all()
    serializer_class = serializers.OrderSerializer


class OrderCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Order.objects.all()
    serializer_class = serializers.OrderSerializerCreate


class OrderUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Order.objects.all()
    serializer_class = serializers.OrderSerializerUpdate
    

class OrderRowList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrderRow.objects.all()
    serializer_class = serializers.OrderRowSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(OrderRowList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class OrderRowRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrderRow.objects.all()
    serializer_class = serializers.OrderRowSerializer


class OrderRowCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrderRow.objects.all()
    serializer_class = serializers.OrderRowSerializerCreate


class OrderRowUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrderRow.objects.all()
    serializer_class = serializers.OrderRowSerializerUpdate
    
    
class VatRowList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.VatRow.objects.all()
    serializer_class = serializers.VatRowSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(VatRowList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class VatRowRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.VatRow.objects.all()
    serializer_class = serializers.VatRowSerializer


class VatRowCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.VatRow.objects.all()
    serializer_class = serializers.VatRowSerializerCreate


class VatRowUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.VatRow.objects.all()
    serializer_class = serializers.VatRowSerializerUpdate


