# -*- coding: utf-8 -*-

import admin_tools
from admin_tools.dashboard import modules, AppIndexDashboard

from django.apps import apps
from django.utils.translation import ugettext_lazy as _

from jmb.core.admin import dashboard as jmb_dashboard


def get_models():
    model_list = []
    app_models = apps.get_app_config('order').get_models()
    for model in app_models:
        model_list.append('{}.{}'.format(
            model.__module__, model.__name__
        ))
    return model_list


class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Order"),
            'display': "tabs",
            'children': (Models(),)
        })
        super(DefaultDashboard, self).__init__(**kwargs)


class AppDashboard(DefaultDashboard):
    pass


class Models(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Order"),
            'models': get_models()
        })
        super(Models, self).__init__(**kwargs)


class DefaultAppDashboard(AppIndexDashboard):
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        self.children.append(
            DefaultDashboard(),
        )


# Used in /admin
jmb_dashboard.register_group(AppDashboard, 'thux.order')
# Used in /admin/order
admin_tools.dashboard.register(DefaultAppDashboard, 'thux.order')
