# -*- coding: utf-8 -*-

# TODO: spostare nei mixin della thux.Ddt


# ORDER
def is_alldelivered(self):
    """
    Restituisce True se l'ordine è stato consegnato o se tutte le righe ordine sono consegnate
    """
    if self.ddt_completed:
        return True

    # verifica se ci sono righe da consegnare
    false_rows = self.rows.filter(ddt=False)
    if len(false_rows) > 0:
        return False
    return True


def set_alldelivered(self):
    """
    Imposta a True se tutte le righe ordine sono state consegnate
    """
    if self.is_alldelivered():
        self.ddt_completed = True
        self.save()


def is_ddtrows_allinvoiced(self):
    """
    Restituisce True se tutte le righe DDT collegate alle righe ordine sono fatturate
    """
    value = False
    for row in self.rows.all():
        for ddtrow in row.ddtrows.all():
            if not ddtrow.ddt.is_allinvoiced() or not self.is_alldelivered():
                value = False
            else:
                value = True
    return value


@transaction.commit_manually
def create_or_append_to_ddt(self, ddt=None, date_d=date.today()):
    '''
    crea o aggiunge ad un DDT le Righe Pratica
    '''
    ## se l'Ordine è già stato consegnato esco
    if self.is_alldelivered():
        transaction.rollback()
        return False
    ## se l'Ordine non è stato accettato esco
    if not self.accepted:
        transaction.rollback()
        return False
    orderrows = self.rows.filter(ddt=False, store_cause__ddt=True)
    if not ddt:
        from jmb.ddt.models import Ddt
        ddt = Ddt(
            owner=self.owner, recipient=self.recipient,
            payment_form=self.payment_form,
            office=self.office, contact=self.contact,
            store_cause=self.store_cause, date_d=date_d,
        )
        ddt.save()

    for row in orderrows:
        row.add_to_ddt(ddt)

    if ddt.ddtrows.count() == 0:
        transaction.rollback()
        return False
    self.set_alldelivered()
    transaction.commit()
    return True


# ORDER ROW
def get_icon_ddt(self):
    img = "<img src='{}img/admin/icon-{}.gif' />".format(
        settings.ADMIN_MEDIA_PREFIX,
        'yes' if self.ddt_completed else 'no'
    )
icon_ddt = property(get_icon_ddt)


def get_last_ddt_date(self):
    """
    Restituisce l'ultima data
    """
    ddtrow = self.ddtrows.all().order_by('-ddt__date_d').last()
    return ddtrow.ddt.date_d if ddtrow else None
last_ddt_date = property(get_last_ddt_date)


def get_deliveredquantity(self):
    """
    Restituisce la quantita totale consegnata
    """
    ddtrows = self.ddtrows.all()
    quantity = 0
    for row in ddtrows:
        quantity += row.quantity
    return quantity
get_deliveredquantity.short_description = _('DQ')


def get_deliveredvalue(self):
    """
    Restituisce l'ammontare totale consegnata
    """
    ddtrows = self.ddtrows.all()
    tot_value = 0
    price = self.get_net_price()
    for row in ddtrows:
        tot_value += row.quantity * price
    return tot_value


def get_notdeliveredquantity(self):
    """
    Restituisce la quantita ancora da consegnare
    """
    return self.quantity - self.get_deliveredquantity()
get_notdeliveredquantity.short_description = _('ND Quantity')


def force_as_delivered(self):
    """
    Chiude una riga ordine in quanto non più da consegnare
    ATTENZIONE! modifica la quantità ordinata
    """
    self.ddt_completed = True
    self.quantity = self.quantity - self.get_notdeliveredquantity()
    self.save()


@transaction.commit_manually
def create_ddt(self, date_d=None, quantity=None, check_quantity=True):
    """
    crea un DDT associando Riga Ordine
    """
    if not date_d:
        date_d = date.today()

    # Esce se l'ordine non è accettato
    if not self.order.accepted:
        transaction.rollback()
        return False, _('order must be accepted before')

    # Esce se la riga ordine è consegnata interamente
    if self.order.is_alldelivered():
        transaction.rollback()
        return False, _('order row already delivered')

    # Crea nuovo ddt
    from jmb.ddt.models import Ddt
    ddt = Ddt(
        owner=self.order.owner, recipient=self.order.recipient,
        bank=self.order.bank, payment_form=self.order.payment_form,
        office=self.order.office, contact=self.order.contact,
        delivery=self.order.delivery, vector=self.order.vector,
        shipping_address=self.order.shipping_address,
        store_cause=self.order.store_cause, date_d=date_d,
    )
    ddt.save()
    # TODO: verificare bene cosa deve tornare object è un erore o l'oggeto creato - non mi piace
    created, object = self.add_to_ddt(ddt, quantity, check_quantity=check_quantity)

    if res:
        transaction.commit()
        return True, ddt
    else:
        transaction.rollback()
        return False, error


def add_to_ddt(self, ddt, quantity=None, check_quantity=True):
    """
    Aggiunge la riga ordine a un DDT.
    Solo la quantità passata viene inserita in DDT e consegnata.
    Se la quantità non è specificata l'intera quantità da consegnare viene inserita nel DDT
    """
    notdeliveredquantity = self.get_notdeliveredquantity()

    # Verifica se la riga ordine non è fatturata
    # Esce se già fatturata
    if self.invoice:
        return False, _('order row already invoiced')

    # Verifica se la quantità della riga ordine da inserire nella riga DDT è POSITIVA
    # Esce se <= 0: non ci sono prodotti da consegnare
    if notdeliveredquantity <= 0:
        return False, _('no product to delivery')

    # Inserisce quantità da consegnare se non viene specificata
    quantity = notdeliveredquantity if not quantity else decimal.Decimal(quantity)

    # Controlla se viene passata una quantità maggiore di quella da consegnare
    # Esce se >
    if check_quantity and quantity > notdeliveredquantity:
        return False, _('DDT quantity greater then order row quantity')

    if not self.check_header_integrity(ddt):
        # Verifica che i dati delle intestazioni dell'ordine e del DDT corrispondono
        # Esce se non c'è corrispondenza
        return False, _('DDT header and order header are different.')

    from jmb.ddt.models import DdtRow
    ddtrow = DdtRow(
        ddt=ddt, orderrow=self, product=self.product, vat=self.vat, store_cause=self.store_cause,
        quantity=quantity, price=self.price, fee=self.fee, discount=self.val_discount,
    )
    ddtrow.save(check_quantity=check_quantity)
    return True, ddtrow

