# -*- coding: utf-8 -*-

# TODO: spostare nei mixin della thux.Suspension


# ORDER
def get_stops(self, date_s=date.today()):
    """
    Restituisce tutte le sospensioni dell'ordine alla data specificata
    """
    return self.suspensions.filter(date_begin__lte=date_s, date_end__gte=date_s)


def is_stopped(self, date_s=date.today()):
    """
    Restituisce True o False se l'ordine è sospeso
    """
    stops = self.suspensions.filter(date_begin__lte=date_s, date_end__gte=date_s)
    return True if stops else False


def is_stopped_in(self, date_begin=date.today(), date_end=date.today()):
    """
    Restituisce True o False se eiste già una sospensione dell'ordine nel periodo specificato.
    """
    stops = self.suspensions.filter(date_begin__lte=date_end, date_end__gte=date_begin)
    return True if stops else False


def is_forever_stopped(self, date_s=date.today()):
    """
    Restituisce True o False se l'ordine è sospeso definitivamente:
    è sospeso definitivamente se non esiste la data di fine
    """
    stops = self.suspensions.filter(date_begin__lte=date_s, date_end__isnull=True)
    return True if stops else False


def set_start(self, cause, date_end=date.today()):
    """
    Crea una sospensione con data inizio = NULL e data fine = giorno precedente a quello passato
    L'ordine è attivo dal giorno passato
    """
    suspension = Suspension(
        order=self, disable_cause=cause, date_begin=None,
        date_end=date_end + timedelta(days=-1)
    )
    suspension.save()


def set_restart(self, date_end=date.today()):
    """
    Attiva l'ordine disattivato da una sospensione modificando la
    data di fine sospensione inserendo il giorno precedente.
    La data passata deve essere compresa nell'intervallo di sospensione.
    """
    suspensions = self.get_stops(date_end)
    for suspension in suspensions:
        suspension.date_end = date_end + timedelta(days=-1)
        suspension.save()


def set_stop(self, cause, date_begin=date.today(), date_end=None):
    """
    Disattiva l'ordine creando una sospensione dalla data di inizio
    alla data di fine.
    Se la data di fine è NULL l'ordine è sospeso definitivamente.
    Non verifica se c'è una sovrapposizione di sospensioni
    CONTROLLI:
    - La data di inizio deve essere <= alla data di fine
    - La data di inizio deve essere > della data di ultima consegna (get_last_date_delivery)
    """
    from jmb.suspension.models import Suspension
    suspension = Suspension(
        order=self, disable_cause=cause,
        date_begin=date_begin, date_end=date_end
    )
    suspension.save()


# ORDER ROW
def get_stops(self, date_s=date.today()):
    """
    Restituisce tutte le sospensioni della riga ordine alla data specificata
    """
    stop = self.suspensions.filter(date_begin__lte=date_s, date_end__gte=date_s)
    return stop


def is_stopped(self, date_s=date.today()):
    """
    Restituisce True o False se la riga ordine è sospesa
    """
    stops = self.suspensions.filter(date_begin__lte=date_s, date_end__gte=date_s)
    return True if stops else False


def is_stopped_in(self, date_begin=date.today(), date_end=date.today()):
    """
    Restituisce True o False se eiste già una sospensione della riga ordine nel periodo specificato.
    """
    stops = self.suspensions.filter(date_begin__lte=date_end, date_end__gte=date_begin)
    return True if stops else False


def is_forever_stopped(self, date_s=date.today()):
    """
    Restituisce True o False se la riga ordine è sospesa definitivamente:
    è sospesa definitivamente se non esiste la data di fine
    """
    stops = self.suspensions.filter(date_begin__lte=date_s, date_end__isnull=True)
    return True if stops else False


def set_start(self, cause, date_end=date.today()):
    """
    Crea una Sospensione con data inizio = NULL e data fine = giorno precedente a quello passato
    La riga ordine è attiva dal giorno passato
    """
    from jmb.suspension.models import Suspension
    suspension = Suspension(
        orderrow=self, disable_cause=cause,
        date_begin=None, date_end=date_end + timedelta(days=-1)
    )
    suspension.save()


def set_restart(self, date_end=date.today()):
    """
    Attiva la riga ordine disattivata da una sospensione modificando la
    data di fine sospensione inserendo il giorno precedente.
    La data passata deve essere compresa nell'intervallo di sospensione.
    """
    suspensions = self.get_stops(date_end)
    for suspension in suspensions:
        suspension.date_end = date_end + timedelta(days=-1)
        suspension.save()


def set_stop(self, cause, date_begin=date.today(), date_end=None):
    """
    Disattiva la riga ordine creando una sospensione dalla data di inizio
    alla data di fine.
    Se la data di fine è NULL la riga ordine è sospesa definitivamente.
    Non verifica se c'è una sovrapposizione di sospensioni
    CONTROLLI:
    - La data di inizio deve essere <= alla data di fine
    - La data di inizio deve essere > della data di ultima consegna (get_last_date_delivery)
    """
    from jmb.suspension.models import Suspension
    suspension = Suspension(
        orderrow=self, disable_cause=cause,
        date_begin=date_begin, date_end=date_end
    )
    suspension.save()
