# -*- coding: utf-8 -*-

from rest_framework import serializers

from thux.product.frontend.serializers import ProductSerializer
from .. import models


class CartRowCreateUpdateSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.CartRow
        fields = ('product', 'quantity')


class CartRowSerializer(serializers.ModelSerializer):
    product_price = serializers.SerializerMethodField()
    product_price_total = serializers.SerializerMethodField()
    product = ProductSerializer(many=False)

    class Meta:
        model = models.CartRow
        fields = (
            'product_price',
            'product_price_total', 'product', 'quantity'
        )

    def get_product_price(self, obj):
        return obj.product.get_price_vat_included()

    def get_product_price_total(self, obj):
        return obj.get_total()


class CartSerializer(serializers.Serializer):
    cart_token = serializers.CharField(max_length=32)
    total = serializers.DecimalField(max_digits=10, decimal_places=2)
    partial_total = serializers.DecimalField(max_digits=10, decimal_places=2)
    shipping_fee = serializers.DecimalField(max_digits=10, decimal_places=2)
    count = serializers.DecimalField(max_digits=10, decimal_places=2)
    cart_rows = CartRowSerializer(many=True)


class InvoiceAddressCartSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.CartInvoiceAddress
        fields = (
            'address_type', 'name', 'number', 'crossed', 'scale',
            'floor', 'zip_code', 'locality', 'province',
            'country', 'post_office'
        )


class ShippingAddressCartSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.CartShippingAddress
        fields = (
            'address_type', 'name', 'number', 'crossed', 'scale',
            'floor', 'zip_code', 'locality', 'province',
            'country', 'post_office'
        )


class NoteCartSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.CartNote
        fields = ('note',)


class OrderSerializer(serializers.ModelSerializer):
    rows = serializers.StringRelatedField(many=True)

    class Meta:
        model = models.Order
        fields = '__all__'


class OrderRowSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.OrderRow
        fields = '__all__'
